@@ -7,7 +7,7 @@
 ;;;; Programmer:    Kevin M. Rosenberg with excerpts from portableaserve
 ;;;; Date Started:  Jun 2003
 ;;;;
-;;;; $Id: sockets.lisp 10151 2004-11-11 21:58:12Z kevin $
+;;;; $Id: sockets.lisp 10174 2004-11-28 20:15:20Z kevin $
 ;;;; *************************************************************************
 
 (in-package #:kmrcl)
@@ -133,12 +133,16 @@ setsockopt SO_REUSEADDR if :reuse is not nil"
   (declare (string dotted))
   (if errorp
       (let ((ll (delimited-string-to-list dotted #\.)))
-	(+ (ash (first ll) 24) (ash (second ll) 16)
-	   (ash (third ll) 8) (fourth ll)))
+	(+ (ash (parse-integer (first ll)) 24) 
+	   (ash (parse-integer (second ll)) 16)
+	   (ash (parse-integer (third ll)) 8) 
+	   (parse-integer (fourth ll))))
     (ignore-errors
       (let ((ll (delimited-string-to-list dotted #\.)))
-	(+ (ash (first ll) 24) (ash (second ll) 16)
-	   (ash (third ll) 8) (fourth ll))))))
+	(+ (ash (parse-integer (first ll)) 24)
+	   (ash (parse-integer (second ll)) 16)
+	   (ash (parse-integer (third ll)) 8) 
+	   (parse-integer (fourth ll)))))))
 
 #+sbcl
 (defun ipaddr-to-hostname (ipaddr &key ignore-cache)
